@@ -16,8 +16,9 @@ namespace DBus
 		static Dictionary<string,Bus> buses = new Dictionary<string,Bus> ();
 
 		static Bus starterBus = null;
-		static Bus systemBus = Address.StarterBusType == "system" ? Starter : Bus.Open (Address.System);
-		static Bus sessionBus = Address.StarterBusType == "session" ? Starter : Bus.Open (Address.Session);
+
+		static Bus systemBus  = Address.StarterBusType=="system"  ? Starter : (Address.System !=null ? Bus.Open (Address.System ) : null);
+		static Bus sessionBus = Address.StarterBusType=="session" ? Starter : (Address.Session != null ? Bus.Open (Address.Session) : null);
 
 		IBus bus;
 		string address;
