@@ -548,8 +548,8 @@ namespace DBus.Protocol
 			if (fis.Length == 0)
 				return default (T);
 
-			if (IsEligibleStruct (typeof (T), fis))
-				return NewMarshalStruct<T> (fis);
+			if (IsEligibleStruct (typeof(T), fis))
+				return (T)MarshalStruct (typeof(T), fis);
 
 			object val = Activator.CreateInstance<T> ();
 
@@ -570,7 +570,10 @@ namespace DBus.Protocol
 			return strct;
 		}
 
-		T NewMarshalStruct<T> (FieldInfo[] fis) where T : struct
+		// Unfortunately in newer Mono, the compiler is not able to infer
+		// that T is a structure for the purpose of acquiring a pointer
+		// causing a compilation error
+		/*T NewMarshalStruct<T> (FieldInfo[] fis) where T : struct
 		{
 			T val = default (T);
 			int sof = Marshal.SizeOf (fis[0].FieldType);
@@ -581,7 +584,7 @@ namespace DBus.Protocol
 			}
 
 			return val;
-		}
+		}*/
 
 		public void ReadNull ()
 		{
