@@ -430,6 +430,12 @@ namespace DBus.Protocol
 			}
 		}
 		
+		public bool IsVariant {
+			get {
+				return data.Length >= 1 && this [0] == DType.Variant;
+			}
+		}
+
 		public bool IsSingleCompleteType
 		{
 			get {
